@@ -36,9 +36,15 @@ def remote_call(remote_endpoint):
     send_dict['endpoint'] = remote_endpoint
 
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-    sock.connect((app.config['GOURD_SERVER_HOST'], app.config['GOURD_SERVER_PORT']))
+    try:
+        sock.connect((app.config['GOURD_SERVER_HOST'], app.config['GOURD_SERVER_PORT']))
+    except Exception, e:
+        return 'connect fail. e: %s' % e
 
-    sock.send(json.dumps(send_dict)+current_app.config['TERMINATOR'])
+    try:
+        sock.send(json.dumps(send_dict)+current_app.config['TERMINATOR'])
+    except Exception, e:
+        return 'send fail. e: %s' % e
 
     socket_map[unique_id] = sock
 
